Module partial_array

Module partial_array 

Immutable partial array implementations.

Structs

PartialArray
An immutable partial array that supports efficient queries in compacted storage.
PartialArrayBuilder
Builder for creating an immutable partial array.

Functions

new_dense
Creates a new builder for a dense partial array of the given length.
new_sparse
Creates a new builder for a sparse partial array of the given length.