PartialArrayBuilder

Struct PartialArrayBuilder 

pub struct PartialArrayBuilder<T, B> { /* private fields */ }
Builder for creating an immutable partial array.

The builder allows you to specify the array length and then add (position, value) pairs. Positions must be added in strictly increasing order.

To get a builder you can use either new_dense or new_sparse.

Implementations

Source

impl<T> PartialArrayBuilder<T, BitVec<Box<[usize]>>>

pub fn set(&mut self, position: usize, value: T)

Sets a value at the given position.

The provided position must be greater than the last position set.

pub fn build(self) -> PartialArray<T, Rank9<BitVec<Box<[usize]>>>>

Builds the immutable dense partial array.

Source

impl<T> PartialArrayBuilder<T, EliasFanoBuilder>

pub fn set(&mut self, position: usize, value: T)

Sets a value at the given position.

The provided position must be greater than the last position set.

pub fn build(self) -> PartialArray<T, SparseIndex<Box<[usize]>>>

Builds the immutable sparse partial array.