BitFieldVec

Struct BitFieldVec 

pub struct BitFieldVec<B: Backend = Vec<usize>> { /* private fields */ }
A vector of bit fields of fixed width (AKA “compact array”, “bit array”, etc.).

See the module documentation for more details.

Implementations

Source

impl<B: Backend<Word: Word>> BitFieldVec<B>

pub unsafe fn from_raw_parts(bits: B, bit_width: usize, len: usize) -> Self

Safety

len * bit_width must be between 0 (included) and the number of bits in bits (included).

pub fn into_raw_parts(self) -> (B, usize, usize)

Returns the backend, the bit width, and the length, consuming this vector.

pub const fn mask(&self) -> B::Word

Returns the mask used to extract values from the vector. This will keep the lowest bit_width bits.

pub unsafe fn map<B2: Backend<Word: Word>>( self, f: impl FnOnce(B) -> B2, ) -> BitFieldVec<B2>

Replaces the backend by applying a function, consuming this vector.

Safety

The caller must ensure that the length is compatible with the new backend.

Source

impl<B: Backend<Word: Word> + AsRef<[B::Word]>> BitFieldVec<B>

pub fn addr_of(&self, index: usize) -> *const B::Word

Gets the address of the item storing (the first part of) the element of given index.

This method is mainly useful for manually prefetching parts of the data structure.

pub fn get_unaligned(&self, index: usize) -> B::Word

Like SliceByValue::index_value, but using unaligned reads.

This method can be used only for bit width smaller than or equal to W::BITS as usize - 8 + 2 or equal to W::BITS as usize - 8 + 4 or W::BITS. Moreover, an additional padding word must be present at the end of the vector.

Note that to guarantee the absence of undefined behavior this method has to perform several tests. Consider using get_unaligned_unchecked if you are sure that the constraints are respected.

Panics

This method will panic if the constraints above are not respected.

pub unsafe fn get_unaligned_unchecked(&self, index: usize) -> B::Word

Like SliceByValue::get_value_unchecked, but using unaligned reads.

Safety

This method can be used only for bit width smaller than or equal to W::BITS as usize - 8 + 2 or equal to W::BITS as usize - 8 + 4 or W::BITS. Moreover, an additional padding word must be present at the end of the vector, and index must be within bounds.

Panics

This method will panic in debug mode if the safety constraints are not respected.

pub fn as_slice(&self) -> &[B::Word]

Returns the backend of the vector as a slice of words.

Source

impl<W: Word> BitFieldVec<Vec<W>>

pub fn new(bit_width: usize, len: usize) -> Self

Creates a new zero-initialized vector of given bit width and length.

pub fn with_capacity(bit_width: usize, capacity: usize) -> Self

Creates an empty vector that doesn’t need to reallocate for up to capacity elements.

pub unsafe fn set_len(&mut self, len: usize)

Sets the length.

Safety

len * bit_width must be at most self.bits.len() * W::BITS as usize. Note that setting the length might result in reading uninitialized data.

pub fn clear(&mut self)

Sets len to 0.

pub const fn bit_width(&self) -> usize

Returns the bit width of the values inside the vector.

pub fn from_slice<S: BitFieldSlice<Value: Word + PrimitiveNumberAs<W>>>( slice: &S, ) -> Result<Self>

Creates a new vector by copying a slice; the bit width will be the minimum width sufficient to hold all values in the slice.

Returns an error if the bit width of the values in slice is larger than W::BITS.

pub fn push(&mut self, value: W)

Adds a value at the end of the vector.

pub fn resize(&mut self, new_len: usize, value: W)

Truncates or extends with value the vector.

pub fn pop(&mut self) -> Option<W>

Removes and returns a value from the end of the vector.

Returns None if the BitFieldVec is empty.

pub fn into_padded(self) -> BitFieldVec<Box<[W]>>

Ensures a padding word is present at the end and converts the backend to Box<[W]>.

The extra word ensures that unaligned reads of size_of::<W>() bytes starting at any byte offset within the data never exceed the allocation. If the allocation already has more words than needed for the data, no word is added.

Source

impl<W: Word> BitFieldVec<Box<[W]>>

pub fn new_padded(bit_width: usize, len: usize) -> Self

Creates a new zero-initialized vector of given bit width and length, with a padding word at the end for safe unaligned reads.

This constructor is useful for structures implementing TryIntoUnaligned that want to avoid reallocations.

Source

impl<B: Backend<Word: Word> + AsRef<[B::Word]>> BitFieldVec<B>

pub fn iter_from(&self, from: usize) -> BitFieldVecIter<'_, B>

pub fn iter(&self) -> BitFieldVecIter<'_, B>