BitVec

Struct BitVec 

pub struct BitVec<B = Vec<usize>> { /* private fields */ }
A bit vector.

Instances can be created using new, with_value, with the convenience macro bit_vec!, or with a FromIterator implementation.

See the module documentation for more details.

Implementations

Source

impl<B> BitVec<B>

pub fn len(&self) -> usize

Returns the number of bits in the bit vector.

This method is equivalent to BitLength::len, but it is provided to reduce ambiguity in method resolution.

pub unsafe fn from_raw_parts(bits: B, len: usize) -> Self

Safety

len must be between 0 (included) and the number of bits in bits (included).

pub fn into_raw_parts(self) -> (B, usize)

pub unsafe fn map<B2>(self, f: impl FnOnce(B) -> B2) -> BitVec<B2>

Modify the bit vector in place.

Safety

This is unsafe because it’s the caller’s responsibility to ensure that that the length is compatible with the modified bits.

Source

impl BitVec<Vec<usize>>

pub fn new(len: usize) -> Self

Creates a new bit vector of length len initialized to false.

pub fn with_value(len: usize, value: bool) -> Self

Creates a new bit vector of length len initialized to value.

pub fn with_capacity(capacity: usize) -> Self

Creates a new zero-length bit vector of given capacity.

Note that the capacity will be rounded up to a multiple of the word size.

pub fn capacity(&self) -> usize

Returns the current capacity of this bit vector.

pub fn push(&mut self, b: bool)

Appends a bit to the end of this bit vector.

pub fn pop(&mut self) -> Option<bool>

Removes the last bit from the bit vector and returns it, or None if it is empty.

pub fn resize(&mut self, new_len: usize, value: bool)

Resizes the bit vector in place, extending it with value if it is necessary.

Source

impl<B: AsRef<[usize]>> BitVec<B>

pub fn to_owned(&self) -> BitVec

Returns an owned copy of the bit vector.