Immutable partial array implementations.
Structs
- Partial
Array - An immutable partial array that supports efficient queries in compacted storage.
- Partial
Array Builder - Builder for creating an immutable partial array.
Functions
- new_
dense - Creates a new builder for a dense partial array of the given length.
- new_
sparse - Creates a new builder for a sparse partial array of the given length.