pub struct PartialArrayBuilder<T, B> { /* private fields */ }Expand description
Builder for creating an immutable partial array.
The builder allows you to specify the array length and then add (position, value) pairs. Positions must be added in strictly increasing order.
To get a builder you can use either new_dense or new_sparse.
Implementations
Sourceimpl<T> PartialArrayBuilder<T, EliasFanoBuilder>
impl<T> PartialArrayBuilder<T, EliasFanoBuilder>