pub struct AtomicBitFieldVec<B: Backend<Word: PrimitiveAtomicUnsigned<Value: Word>> = Vec<Atomic<usize>>> { /* private fields */ }Expand description
A tentatively thread-safe vector of bit fields of fixed width (AKA “compact arrays”, “bit array”, etc.)
This implementation provides some concurrency guarantees, albeit not full-fledged thread safety: more precisely, we can guarantee thread-safety if the bit width is a power of two; otherwise, concurrent writes to values that cross word boundaries might end up in different threads succeeding in writing only part of a value. If the user can guarantee that no two threads ever write to the same boundary-crossing value, then no race condition can happen.
See the module documentation for more details.
Implementations
Sourceimpl<B: Backend<Word: PrimitiveAtomicUnsigned<Value: Word>>> AtomicBitFieldVec<B>
impl<B: Backend<Word: PrimitiveAtomicUnsigned<Value: Word>>> AtomicBitFieldVec<B>
Sourcepub unsafe fn from_raw_parts(bits: B, bit_width: usize, len: usize) -> Self
pub unsafe fn from_raw_parts(bits: B, bit_width: usize, len: usize) -> Self
Safety
len * bit_width must be between 0 (included) and the number of
bits in bits (included).
Sourcepub fn into_raw_parts(self) -> (B, usize, usize)
pub fn into_raw_parts(self) -> (B, usize, usize)
Returns the backend, the bit width, and the length, consuming this vector.
Sourcepub const fn mask(&self) -> <B::Word as PrimitiveAtomic>::Value
pub const fn mask(&self) -> <B::Word as PrimitiveAtomic>::Value
Returns the mask used to extract values from the vector.
This will keep the lowest bit_width bits.
Sourceimpl<B: Backend<Word: PrimitiveAtomicUnsigned<Value: Word>> + AsRef<[B::Word]>> AtomicBitFieldVec<B>
impl<B: Backend<Word: PrimitiveAtomicUnsigned<Value: Word>> + AsRef<[B::Word]>> AtomicBitFieldVec<B>
Sourceimpl<A: PrimitiveAtomicUnsigned<Value: Word>> AtomicBitFieldVec<Vec<A>>
impl<A: PrimitiveAtomicUnsigned<Value: Word>> AtomicBitFieldVec<Vec<A>>