pub struct BitFieldVec<B: Backend = Vec<usize>> { /* private fields */ }Expand description
A vector of bit fields of fixed width (AKA “compact array”, “bit array”, etc.).
See the module documentation for more details.
Implementations
Sourceimpl<B: Backend<Word: Word>> BitFieldVec<B>
impl<B: Backend<Word: Word>> BitFieldVec<B>
Sourcepub unsafe fn from_raw_parts(bits: B, bit_width: usize, len: usize) -> Self
pub unsafe fn from_raw_parts(bits: B, bit_width: usize, len: usize) -> Self
Safety
len * bit_width must be between 0 (included) and the number of
bits in bits (included).
Sourcepub fn into_raw_parts(self) -> (B, usize, usize)
pub fn into_raw_parts(self) -> (B, usize, usize)
Returns the backend, the bit width, and the length, consuming this vector.
Sourceimpl<B: Backend<Word: Word> + AsRef<[B::Word]>> BitFieldVec<B>
impl<B: Backend<Word: Word> + AsRef<[B::Word]>> BitFieldVec<B>
Sourcepub fn addr_of(&self, index: usize) -> *const B::Word
pub fn addr_of(&self, index: usize) -> *const B::Word
Gets the address of the item storing (the first part of) the element of given index.
This method is mainly useful for manually prefetching parts of the data structure.
Sourcepub fn get_unaligned(&self, index: usize) -> B::Word
pub fn get_unaligned(&self, index: usize) -> B::Word
Like SliceByValue::index_value, but using unaligned reads.
This method can be used only for bit width smaller than or equal to
W::BITS as usize - 8 + 2 or equal to W::BITS as usize - 8 + 4 or W::BITS. Moreover,
an additional padding word must be present at the end of the vector.
Note that to guarantee the absence of undefined behavior this method
has to perform several tests. Consider using
get_unaligned_unchecked if you are sure that the constraints are
respected.
Panics
This method will panic if the constraints above are not respected.
Sourcepub unsafe fn get_unaligned_unchecked(&self, index: usize) -> B::Word
pub unsafe fn get_unaligned_unchecked(&self, index: usize) -> B::Word
Like SliceByValue::get_value_unchecked, but using unaligned reads.
Safety
This method can be used only for bit width smaller than or equal to
W::BITS as usize - 8 + 2 or equal to W::BITS as usize - 8 + 4 or W::BITS. Moreover,
an additional padding word must be present at the end of the vector,
and index must be within bounds.
Panics
This method will panic in debug mode if the safety constraints are not respected.
Sourceimpl<W: Word> BitFieldVec<Vec<W>>
impl<W: Word> BitFieldVec<Vec<W>>
Sourcepub fn new(bit_width: usize, len: usize) -> Self
pub fn new(bit_width: usize, len: usize) -> Self
Creates a new zero-initialized vector of given bit width and length.
Sourcepub fn with_capacity(bit_width: usize, capacity: usize) -> Self
pub fn with_capacity(bit_width: usize, capacity: usize) -> Self
Creates an empty vector that doesn’t need to reallocate for up to
capacity elements.
Sourcepub unsafe fn set_len(&mut self, len: usize)
pub unsafe fn set_len(&mut self, len: usize)
Sets the length.
Safety
len * bit_width must be at most self.bits.len() * W::BITS as usize. Note that
setting the length might result in reading uninitialized data.
Sourcepub fn from_slice<S: BitFieldSlice<Value: Word + PrimitiveNumberAs<W>>>(
slice: &S,
) -> Result<Self>
pub fn from_slice<S: BitFieldSlice<Value: Word + PrimitiveNumberAs<W>>>( slice: &S, ) -> Result<Self>
Creates a new vector by copying a slice; the bit width will be the minimum width sufficient to hold all values in the slice.
Returns an error if the bit width of the values in slice is larger than
W::BITS.
Sourcepub fn pop(&mut self) -> Option<W>
pub fn pop(&mut self) -> Option<W>
Removes and returns a value from the end of the vector.
Returns None if the BitFieldVec is empty.
Sourcepub fn into_padded(self) -> BitFieldVec<Box<[W]>>
pub fn into_padded(self) -> BitFieldVec<Box<[W]>>
Ensures a padding word is present at the end and converts the
backend to Box<[W]>.
The extra word ensures that unaligned reads of size_of::<W>()
bytes starting at any byte offset within the data never exceed the
allocation. If the allocation already has more words than needed
for the data, no word is added.
Sourceimpl<W: Word> BitFieldVec<Box<[W]>>
impl<W: Word> BitFieldVec<Box<[W]>>
Sourcepub fn new_padded(bit_width: usize, len: usize) -> Self
pub fn new_padded(bit_width: usize, len: usize) -> Self
Creates a new zero-initialized vector of given bit width and length, with a padding word at the end for safe unaligned reads.
This constructor is useful for structures implementing
TryIntoUnaligned that want to avoid reallocations.