pub struct BitVec<B = Vec<usize>> { /* private fields */ }Expand description
A bit vector.
Instances can be created using new,
with_value, with the convenience macro
bit_vec!, or with a FromIterator
implementation.
See the module documentation for more details.
Implementations
Sourceimpl<B> BitVec<B>
impl<B> BitVec<B>
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of bits in the bit vector.
This method is equivalent to BitLength::len, but it is provided to
reduce ambiguity in method resolution.
Sourcepub unsafe fn from_raw_parts(bits: B, len: usize) -> Self
pub unsafe fn from_raw_parts(bits: B, len: usize) -> Self
Safety
len must be between 0 (included) and the number of
bits in bits (included).
pub fn into_raw_parts(self) -> (B, usize)
Sourceimpl BitVec<Vec<usize>>
impl BitVec<Vec<usize>>
Sourcepub fn with_value(len: usize, value: bool) -> Self
pub fn with_value(len: usize, value: bool) -> Self
Creates a new bit vector of length len initialized to value.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Creates a new zero-length bit vector of given capacity.
Note that the capacity will be rounded up to a multiple of the word size.