pub fn lcp_len(xs: &[u8], ys: &[u8]) -> usizeExpand description
Returns the length of the longest common prefix (in bytes) between two byte slices. This is the byte position of the first mismatch, or the length of the shorter slice if one is a prefix of the other.
Uses chunks_exact(128) to enable SIMD auto-vectorization in the common
case where both slices share a long common prefix.